@@ -30,7 +30,6 @@
 
 #include <sys/types.h>
 
-#include <pwd.h>
 #include <unistd.h>
 
 
@@ -42,8 +41,6 @@
    `topen' declaration.  */
 #include "externs.h"
 
-long lseek ();
-
 #ifndef L_SET
 #define L_SET 0
 #endif
@@ -51,10 +48,6 @@ long lseek ();
 #define L_INCR 1
 #endif
 
-void exit ();
-
-long time ();
-
 static void
 date (day, daylen)
      char *day;
@@ -165,7 +158,7 @@ umoria.");
       return;
     }
 
-  player_uid = getuid ();
+  player_uid = 0;
 
   /* set the static fileptr in save.c to the highscore file pointer */
   set_fileptr (highscore_fp);
@@ -238,7 +231,7 @@ umoria.");
   /* set the static fileptr in save.c to the highscore file pointer */
   set_fileptr (highscore_fp);
 
-  player_uid = getuid ();
+  player_uid = 0;
 
   rd_highscore (&score);
   while (!feof (highscore_fp))
@@ -414,7 +407,7 @@ are not saved.");
 
   new_entry.points = total_points ();
   new_entry.birth_date = birth_date;
-  new_entry.uid = getuid ();
+  new_entry.uid = 0;
   new_entry.mhp = py.misc.mhp;
   new_entry.chp = py.misc.chp;
   new_entry.dun_level = dun_level;
