@@ -277,7 +277,7 @@ identify (item)
 
   i_ptr = &inventory[*item];
 
-  if (i_ptr->flags & TR_CURSED)
+  if (set_book (i_ptr) == FALSE && i_ptr->flags & TR_CURSED)
     add_inscribe (i_ptr, ID_DAMD);
 
   if (!known1_p (i_ptr))
@@ -522,6 +522,12 @@ objdes (out_val, out_val_len, i_ptr, pref)
     case TV_INVIS_TRAP:
     case TV_VIS_TRAP:
     case TV_UP_STAIR:
+      if (i_ptr->subval == 0)
+        snprintf (out_val, out_val_len, "%s.  It is expired.", 
+                  object_list[i_ptr->index].name);
+      else
+        snprintf (out_val, out_val_len, "%s.", object_list[i_ptr->index].name);
+      return;
     case TV_DOWN_STAIR:
       snprintf (out_val, out_val_len, "%s.", object_list[i_ptr->index].name);
       return;
