@@ -22,7 +22,6 @@
 #include "config.h"
 #include <stdlib.h>
 #include <curses.h>
-#include <termios.h>
 #include <string.h>
 
 #include <curses.h>
@@ -30,15 +29,17 @@
 
 #include <ctype.h>
 
-#include <sys/ioctl.h>
 #include <signal.h>
 
 #include <sys/types.h>
-#include <sys/wait.h>
 #include <unistd.h>
 #include <string.h>
 
+#if ! WINDOWS
+#include <sys/wait.h>
+#include <sys/ioctl.h>
 #include <termios.h>
+#endif
 
 /* These are included after other includes (particularly curses.h)
    to avoid redefintion warnings. */
@@ -56,8 +57,6 @@ char *getenv ();
 void exit ();
 unsigned sleep ();
 
-static struct termios save_termio;
-
 static int curses_on = FALSE;
 static WINDOW *savescr;		/* Spare window for saving the screen. -CJS- */
 
@@ -77,8 +76,6 @@ suspend ()
 void
 init_curses ()
 {
-  ioctl (0, TCGETA, (char *) &save_termio);
-
   if (initscr () == NULL)
     {
       printf ("Error allocating screen in curses package.\n");
@@ -128,33 +125,15 @@ init_curses ()
 void
 moriaterm ()
 {
-  struct termios tbuf;
+  char *termtype = getenv("TERM");
+  if (termtype)
+    tgetent(0, termtype);
 
   curses_on = TRUE;
-  use_value cbreak();
-  //use_value crmode ();
-  use_value noecho ();
-  use_value nonl ();
-  /* can not use nonl(), because some curses do not handle it correctly */
-  ioctl (0, TCGETA, (char *) &tbuf);
-  /* disable all of the normal special control characters */
-  tbuf.c_cc[VINTR] = (char) 3;	/* control-C */
-  tbuf.c_cc[VQUIT] = (char) -1;
-  tbuf.c_cc[VERASE] = (char) -1;
-  tbuf.c_cc[VKILL] = (char) -1;
-  tbuf.c_cc[VEOF] = (char) -1;
+  cbreak();
+  noecho ();
+  nonl ();
 
-  /* don't know what these are for */
-  tbuf.c_cc[VEOL] = (char) -1;
-#ifdef VEOL2
-  tbuf.c_cc[VEOL2] = (char) -1;
-#endif
-
-  /* stuff needed when !icanon, i.e. cbreak/raw mode */
-  tbuf.c_cc[VMIN] = 1;		/* Input should wait for at least 1 char */
-  tbuf.c_cc[VTIME] = 0;		/* no matter how long that takes. */
-
-  ioctl (0, TCSETA, (char *) &tbuf);
 }
 
 
@@ -209,7 +188,6 @@ restore_term ()
   endwin ();			/* exit curses */
   fflush (stdout);
   /* restore the saved values of the special chars */
-  ioctl (0, TCSETA, (char *) &save_termio);
   curses_on = FALSE;
 }
 
@@ -217,6 +195,7 @@ restore_term ()
 void
 shell_out ()
 {
+#if ! WINDOWS
   struct termios tbuf;
   int val;
   char *str;
@@ -227,7 +206,7 @@ shell_out ()
   put_buffer ("[Entering shell, type 'exit' to resume your game.]\n", 0, 0);
   put_qio ();
 
-  ioctl (0, TCGETA, (char *) &tbuf);
+  //ioctl (0, TCGETA, (char *) &tbuf);
   /* would call nl() here if could use nl()/nonl(), see moriaterm() */
   use_value nocbreak();
   use_value echo ();
@@ -237,7 +216,6 @@ shell_out ()
   if (val == 0)
     {
       default_signals ();
-      ioctl (0, TCSETA, (char *) &save_termio);
       /* close scoreboard descriptor */
       fclose (highscore_fp);
       if ((str = getenv ("SHELL")))
@@ -263,6 +241,7 @@ shell_out ()
   /* have to disable ^Y for tunneling */
   ioctl (0, TCSETA, (char *) &tbuf);
   wrefresh (curscr);
+#endif
 }
 
 /* Returns a single character input from the terminal.	This silently -CJS-
