@@ -26,9 +26,6 @@
 #include <sys/types.h>
 #include <stdlib.h>
 
-long time ();
-struct tm *localtime ();
-
 /* gets a new random seed for the random number generator */
 void
 init_seeds (seed)
