@@ -1236,14 +1236,16 @@ display_char ()
 void
 get_name ()
 {
-  prt ("Enter your player's name  [press <RETURN> when finished]", 21, 2);
-  put_buffer (&blank_string[BLANK_LENGTH - 23], 2, 15);
-  if (!get_string (py.misc.name, 2, 15, 23) || py.misc.name[0] == 0)
-    {
-      user_name (py.misc.name, sizeof (py.misc.name));
-      put_buffer (py.misc.name, 2, 15);
-    }
-  clear_from (20);
+  while (1)
+   {
+     prt ("Enter your player's name  [press |key <Return>| when finished]", 21, 2);
+     put_buffer (&blank_string[BLANK_LENGTH - 23], 2, 15);
+     if (!get_string (py.misc.name, 2, 15, 23) || py.misc.name[0] == 0)
+       continue;
+     clear_from (20);
+     if (py.misc.name[0] != 0)
+       break;
+   }
 }
 
 
@@ -2304,7 +2306,7 @@ insert_lnum (object_str, object_str_siz, mtc_str, number, show_sign)
   tmp_str = object_str;
   do
     {
-      string = index (tmp_str, mtc_str[0]);
+      string = strchr (tmp_str, mtc_str[0]);
       if (string == 0)
 	flag = 0;
       else
