@@ -218,7 +218,7 @@ display_item (store_num, pos)
      int store_num, pos;
 {
   register int i;
-  register int32 j;
+  register int j;
   register store_type *s_ptr;
   inven_type *i_ptr;
   bigvtype out_val1, out_val2;
@@ -300,7 +300,7 @@ store_prt_gold ()
 {
   vtype out_val;
 
-  snprintf (out_val, sizeof (out_val), "Gold Remaining : %ld", py.misc.au);
+  snprintf (out_val, sizeof (out_val), "Gold Remaining : %ld", (int)py.misc.au);
   prt (out_val, 18, 17);
 }
 
@@ -530,7 +530,7 @@ receive_offer (store_num, comment, new_offer, last_offer, num_offer, factor)
 static int
 purchase_haggle (store_num, price, item, best_price)
      int store_num;
-     int32 *price;
+     int *price;
      inven_type *item;
      int *best_price;
 {
@@ -739,7 +739,7 @@ purchase_haggle (store_num, price, item, best_price)
 static int
 sell_haggle (store_num, price, item, item_val)
      int store_num;
-     int32 *price;
+     int *price;
      inven_type *item;
      int item_val;
 {
@@ -992,7 +992,7 @@ store_purchase (store_num, cur_top)
      int store_num;
      int *cur_top;
 {
-  int32 price;
+  int price;
   register int i, choice;
   bigvtype out_val, tmp_str;
   register store_type *s_ptr;
@@ -1111,7 +1111,7 @@ store_sell (store_num, cur_top)
      int store_num, *cur_top;
 {
   int item_val, item_pos;
-  int32 price;
+  int price;
   bigvtype out_val, tmp_str;
   inven_type sold_obj;
   register int sell, choice, flag;
