@@ -31,7 +31,6 @@ typedef char vtype[VTYPESIZ];
 /* note that since its output can easily exceed 80 characters, objdes must
    always be called with a bigvtype as the first paramter */
 typedef char bigvtype[BIGVTYPESIZ];
-typedef char stat_type[7];
 
 /* Many of the character fields used to be fixed length, which greatly
    increased the size of the executable.  I have replaced many fixed
@@ -192,6 +191,7 @@ typedef struct player_type
     int8u acid_resist;		/* Resistance to acid  */
     int8u regenerate;		/* Regenerate hit pts  */
     int8u lght_resist;		/* Resistance to light */
+    int8u gas_resist;		/* Resistance to gas   */
     int8u ffall;		/* No damage falling   */
     int8u sustain_str;		/* Keep strength       */
     int8u sustain_int;		/* Keep intelligence   */
